Module backends

Module backends 

Storage backend implementations

This module defines the trait that all storage backends must implement, and provides implementations for various cloud storage providers.

Modules

dropbox
Dropbox storage backend implementation
gdrive
Google Drive storage backend implementation
http
HTTP storage backend implementation
local_fs
Local filesystem backend implementation
postgresql
PostgreSQL storage backend implementation
s3
AWS S3 storage backend implementation

Traits

StorageBackend
Trait that all storage backends must implement