Module error

Module error 

Error types for the library

This module defines all error types that can occur when using the virtual table. We use thiserror for ergonomic error handling and automatic Display/Error implementations.

Enums

VTableError
The main error type for this library

Type Aliases

Result
Convenience Result type for this library